@@ -1,14 +1,20 @@
 # -*- coding: utf-8 -*-
 
-# ########################## Copyrights and license ############################
+############################ Copyrights and license ############################
 #                                                                              #
 # Copyright 2012 Vincent Jacques <vincent@vincent-jacques.net>                 #
 # Copyright 2012 Zearin <zearin@gonk.net>                                      #
 # Copyright 2013 AKFish <akfish@gmail.com>                                     #
 # Copyright 2013 Vincent Jacques <vincent@vincent-jacques.net>                 #
+# Copyright 2014 Thialfihar <thi@thialfihar.org>                               #
+# Copyright 2014 Vincent Jacques <vincent@vincent-jacques.net>                 #
+# Copyright 2016 Jannis Gebauer <ja.geb@me.com>                                #
+# Copyright 2016 Peter Buckley <dx-pbuckley@users.noreply.github.com>          #
+# Copyright 2018 Wan Liuyang <tsfdye@gmail.com>                                #
+# Copyright 2018 sfdye <tsfdye@gmail.com>                                      #
 #                                                                              #
 # This file is part of PyGithub.                                               #
-# http://pygithub.github.io/PyGithub/v1/index.html                             #
+# http://pygithub.readthedocs.io/                                              #
 #                                                                              #
 # PyGithub is free software: you can redistribute it and/or modify it under    #
 # the terms of the GNU Lesser General Public License as published by the Free  #
@@ -23,21 +29,18 @@
 # You should have received a copy of the GNU Lesser General Public License     #
 # along with PyGithub. If not, see <http://www.gnu.org/licenses/>.             #
 #                                                                              #
-# ##############################################################################
+################################################################################
+
 
 import base64
-import sys
 
 import github.GithubObject
 import github.Repository
 
 
-atLeastPython3 = sys.hexversion >= 0x03000000
-
-
 class ContentFile(github.GithubObject.CompletableGithubObject):
     """
-    This class represents ContentFiles as returned for example by http://developer.github.com/v3/todo
+    This class represents ContentFiles. The reference can be found here https://developer.github.com/v3/repos/contents/#get-contents
     """
 
     def __repr__(self):
@@ -54,11 +57,15 @@ class ContentFile(github.GithubObject.CompletableGithubObject):
     @property
     def decoded_content(self):
         assert self.encoding == "base64", "unsupported encoding: %s" % self.encoding
-        if atLeastPython3:
-            content = bytearray(self.content, "utf-8")  # pragma no cover (covered by tests with Python 3.2)
-        else:
-            content = self.content
-        return base64.b64decode(content)
+        return base64.b64decode(bytearray(self.content, "utf-8"))
+
+    @property
+    def download_url(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._download_url)
+        return self._download_url.value
 
     @property
     def encoding(self):
@@ -84,6 +91,14 @@ class ContentFile(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._html_url)
         return self._html_url.value
 
+    @property
+    def license(self):
+        """
+        :type: :class:`github.License.License`
+        """
+        self._completeIfNotSet(self._license)
+        return self._license.value
+
     @property
     def name(self):
         """
@@ -143,11 +158,22 @@ class ContentFile(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._url)
         return self._url.value
 
+    @property
+    def text_matches(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._text_matches)
+        return self._text_matches.value
+
     def _initAttributes(self):
         self._content = github.GithubObject.NotSet
+        self._text_matches = github.GithubObject.NotSet
         self._encoding = github.GithubObject.NotSet
+        self._download_url = github.GithubObject.NotSet
         self._git_url = github.GithubObject.NotSet
         self._html_url = github.GithubObject.NotSet
+        self._license = github.GithubObject.NotSet
         self._name = github.GithubObject.NotSet
         self._path = github.GithubObject.NotSet
         self._repository = github.GithubObject.NotSet
@@ -158,12 +184,16 @@ class ContentFile(github.GithubObject.CompletableGithubObject):
     def _useAttributes(self, attributes):
         if "content" in attributes:  # pragma no branch
             self._content = self._makeStringAttribute(attributes["content"])
+        if "download_url" in attributes:  # pragma no branch
+            self._download_url = self._makeStringAttribute(attributes["download_url"])
         if "encoding" in attributes:  # pragma no branch
             self._encoding = self._makeStringAttribute(attributes["encoding"])
         if "git_url" in attributes:  # pragma no branch
             self._git_url = self._makeStringAttribute(attributes["git_url"])
         if "html_url" in attributes:  # pragma no branch
             self._html_url = self._makeStringAttribute(attributes["html_url"])
+        if "license" in attributes:  # pragma no branch
+            self._license = self._makeClassAttribute(github.License.License, attributes["license"])
         if "name" in attributes:  # pragma no branch
             self._name = self._makeStringAttribute(attributes["name"])
         if "path" in attributes:  # pragma no branch
@@ -178,3 +208,5 @@ class ContentFile(github.GithubObject.CompletableGithubObject):
             self._type = self._makeStringAttribute(attributes["type"])
         if "url" in attributes:  # pragma no branch
             self._url = self._makeStringAttribute(attributes["url"])
+        if "text_matches" in attributes:  # pragma no branch
+            self._text_matches = self._makeListOfDictsAttribute(attributes["text_matches"])
