@@ -10,6 +10,7 @@
 # Copyright 2014 Vincent Jacques <vincent@vincent-jacques.net>                 #
 # Copyright 2016 Jannis Gebauer <ja.geb@me.com>                                #
 # Copyright 2016 Peter Buckley <dx-pbuckley@users.noreply.github.com>          #
+# Copyright 2018 Mateusz Loskot <mateusz@loskot.net>                           #
 # Copyright 2018 sfdye <tsfdye@gmail.com>                                      #
 #                                                                              #
 # This file is part of PyGithub.                                               #
@@ -30,10 +31,14 @@
 #                                                                              #
 ################################################################################
 
-import urllib.request, urllib.parse, urllib.error
+
+import six.moves.urllib.parse
 
 import github.GithubObject
 
+from . import Consts
+import six
+
 
 class Label(github.GithubObject.CompletableGithubObject):
     """
@@ -93,9 +98,9 @@ class Label(github.GithubObject.CompletableGithubObject):
         :param description: string
         :rtype: None
         """
-        assert isinstance(name, str), name
-        assert isinstance(color, str), color
-        assert description is github.GithubObject.NotSet or isinstance(description, str), description
+        assert isinstance(name, (str, six.text_type)), name
+        assert isinstance(color, (str, six.text_type)), color
+        assert description is github.GithubObject.NotSet or isinstance(description, (str, six.text_type)), description
         post_parameters = {
             "name": name,
             "color": color,
@@ -106,13 +111,13 @@ class Label(github.GithubObject.CompletableGithubObject):
             "PATCH",
             self.url,
             input=post_parameters,
-            headers={'Accept': 'application/vnd.github.symmetra-preview+json'}
+            headers={'Accept': Consts.mediaTypeLabelDescriptionSearchPreview}
         )
         self._useAttributes(data)
 
     @property
     def _identity(self):
-        return urllib.parse.quote(self.name)
+        return six.moves.urllib.parse.quote(self.name)
 
     def _initAttributes(self):
         self._color = github.GithubObject.NotSet
