@@ -32,12 +32,14 @@
 #                                                                              #
 ################################################################################
 
+
 import github.GithubObject
 import github.PaginatedList
 
 import github.NamedUser
 
 from . import Consts
+import six
 
 
 class Migration(github.GithubObject.CompletableGithubObject):
@@ -176,7 +178,7 @@ class Migration(github.GithubObject.CompletableGithubObject):
         :param repo_name: str
         :rtype: None
         """
-        assert isinstance(repo_name, str), repo_name
+        assert isinstance(repo_name, (str, six.text_type)), repo_name
         headers, data = self._requester.requestJsonAndCheck(
             "DELETE",
             self.url + "/repos/" + repo_name + "/lock",
