@@ -37,6 +37,7 @@
 #                                                                              #
 ################################################################################
 
+
 import datetime
 
 import github.GithubObject
@@ -49,6 +50,7 @@ import github.Permissions
 import github.Plan
 import github.Organization
 import github.Event
+import six
 
 
 class NamedUser(github.GithubObject.CompletableGithubObject):
@@ -225,6 +227,22 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._id)
         return self._id.value
 
+    @property
+    def invitation_teams_url(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._invitation_teams_url)
+        return self._invitation_teams_url.value
+
+    @property
+    def inviter(self):
+        """
+        :type: github.NamedUser.NamedUser
+        """
+        self._completeIfNotSet(self._inviter)
+        return self._inviter.value
+
     @property
     def location(self):
         """
@@ -321,6 +339,14 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._repos_url)
         return self._repos_url.value
 
+    @property
+    def role(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._role)
+        return self._role.value
+
     @property
     def site_admin(self):
         """
@@ -353,6 +379,14 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._suspended_at)
         return self._suspended_at.value
 
+    @property
+    def team_count(self):
+        """
+        :type: integer
+        """
+        self._completeIfNotSet(self._team_count)
+        return self._team_count.value
+
     @property
     def total_private_repos(self):
         """
@@ -504,7 +538,7 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         :param name: string
         :rtype: :class:`github.Repository.Repository`
         """
-        assert isinstance(name, str), name
+        assert isinstance(name, (str, six.text_type)), name
         headers, data = self._requester.requestJsonAndCheck(
             "GET",
             "/repos/" + self.login + "/" + name
@@ -520,9 +554,9 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         :param direction: string
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Repository.Repository`
         """
-        assert type is github.GithubObject.NotSet or isinstance(type, str), type
-        assert sort is github.GithubObject.NotSet or isinstance(sort, str), sort
-        assert direction is github.GithubObject.NotSet or isinstance(direction, str), direction
+        assert type is github.GithubObject.NotSet or isinstance(type, (str, six.text_type)), type
+        assert sort is github.GithubObject.NotSet or isinstance(sort, (str, six.text_type)), sort
+        assert direction is github.GithubObject.NotSet or isinstance(direction, (str, six.text_type)), direction
         url_parameters = dict()
         if type is not github.GithubObject.NotSet:
             url_parameters["type"] = type
@@ -590,6 +624,18 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
     def _identity(self):
         return self.login
 
+    def get_organization_membership(self, org):
+        """
+        :calls: `GET /user/memberships/orgs/:org <https://developer.github.com/v3/orgs/members/#get-your-organization-membership>`_
+        :rtype: :class:`github.Membership.Membership`
+        """
+        assert isinstance(org, int)
+        headers, data = self._requester.requestJsonAndCheck(
+            "GET",
+            "/user/memberships/orgs/" + str(org)
+        )
+        return github.Membership.Membership(self._requester, headers, data, completed=True)
+
     def _initAttributes(self):
         self._avatar_url = github.GithubObject.NotSet
         self._bio = github.GithubObject.NotSet
@@ -610,6 +656,8 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         self._hireable = github.GithubObject.NotSet
         self._html_url = github.GithubObject.NotSet
         self._id = github.GithubObject.NotSet
+        self._invitation_teams_url = github.GithubObject.NotSet
+        self._inviter = github.GithubObject.NotSet
         self._location = github.GithubObject.NotSet
         self._login = github.GithubObject.NotSet
         self._name = github.GithubObject.NotSet
@@ -623,10 +671,12 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         self._public_repos = github.GithubObject.NotSet
         self._received_events_url = github.GithubObject.NotSet
         self._repos_url = github.GithubObject.NotSet
+        self._role = github.GithubObject.NotSet
         self._site_admin = github.GithubObject.NotSet
         self._starred_url = github.GithubObject.NotSet
         self._subscriptions_url = github.GithubObject.NotSet
         self._suspended_at = github.GithubObject.NotSet
+        self._team_count = github.GithubObject.NotSet
         self._total_private_repos = github.GithubObject.NotSet
         self._type = github.GithubObject.NotSet
         self._updated_at = github.GithubObject.NotSet
@@ -671,6 +721,10 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
             self._html_url = self._makeStringAttribute(attributes["html_url"])
         if "id" in attributes:  # pragma no branch
             self._id = self._makeIntAttribute(attributes["id"])
+        if "invitation_teams_url" in attributes:  # pragma no branch
+            self._invitation_teams_url = self._makeStringAttribute(attributes["invitation_teams_url"])
+        if "inviter" in attributes:  # pragma no branch
+            self._inviter = self._makeClassAttribute(github.NamedUser.NamedUser, attributes["inviter"])
         if "location" in attributes:  # pragma no branch
             self._location = self._makeStringAttribute(attributes["location"])
         if "login" in attributes:  # pragma no branch
@@ -697,6 +751,8 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
             self._received_events_url = self._makeStringAttribute(attributes["received_events_url"])
         if "repos_url" in attributes:  # pragma no branch
             self._repos_url = self._makeStringAttribute(attributes["repos_url"])
+        if "role" in attributes:  # pragma no branch
+            self._role = self._makeStringAttribute(attributes["role"])
         if "site_admin" in attributes:  # pragma no branch
             self._site_admin = self._makeBoolAttribute(attributes["site_admin"])
         if "starred_url" in attributes:  # pragma no branch
@@ -705,6 +761,8 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
             self._subscriptions_url = self._makeStringAttribute(attributes["subscriptions_url"])
         if "suspended_at" in attributes:  # pragma no branch
             self._suspended_at = self._makeDatetimeAttribute(attributes["suspended_at"])
+        if "team_count" in attributes:
+            self._team_count = self._makeIntAttribute(attributes["team_count"])
         if "total_private_repos" in attributes:  # pragma no branch
             self._total_private_repos = self._makeIntAttribute(attributes["total_private_repos"])
         if "type" in attributes:  # pragma no branch
